package SSIS::Package::DTSTask::FOREACHLOOP;

use 5.010;
use Mouse;

extends 'SSIS::Package::DTSTask';

=head1 NAME

SSIS::Package::DTSTask::FOREACHLOOP - SSIS package task FOREACHLOOP by Ded MedVed

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';



1 ;

__DATA__

1; # End of SSIS::Package::DTSTask::FOREACHLOOP

